package com.yijia.integral.service;

import java.util.List;
import com.yijia.integral.domain.IntegralOrder;

/**
 * 积分消费订单Service接口
 * 
 * @author yijia
 * @date 2021-02-24
 */
public interface IIntegralOrderService 
{
    /**
     * 查询积分消费订单
     * 
     * @param id 积分消费订单ID
     * @return 积分消费订单
     */
    public IntegralOrder selectIntegralOrderById(Long id);

    /**
     * 查询积分消费订单列表
     * 
     * @param integralOrder 积分消费订单
     * @return 积分消费订单集合
     */
    public List<IntegralOrder> selectIntegralOrderList(IntegralOrder integralOrder);

    /**
     * 新增积分消费订单
     * 
     * @param integralOrder 积分消费订单
     * @return 结果
     */
    public int insertIntegralOrder(IntegralOrder integralOrder);

    /**
     * 修改积分消费订单
     * 
     * @param integralOrder 积分消费订单
     * @return 结果
     */
    public int updateIntegralOrder(IntegralOrder integralOrder);

    /**
     * 批量删除积分消费订单
     * 
     * @param ids 需要删除的积分消费订单ID
     * @return 结果
     */
    public int deleteIntegralOrderByIds(Long[] ids);

    /**
     * 删除积分消费订单信息
     * 
     * @param id 积分消费订单ID
     * @return 结果
     */
    public int deleteIntegralOrderById(Long id);
}
